import gy_multiprocessing.multiprocessing
import gy_multiprocessing.multithreading


def hello_world() -> None:
    print("Hello world!")
